// Copyright 2016 The Rust Project Developers. See the COPYRIGHT
// file at the top-level directory of this distribution and at
// http://rust-lang.org/COPYRIGHT.
//
// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
// http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
// <LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
// option. This file may not be copied, modified, or distributed
// except according to those terms.

fn f() {}
fn g<'a>() {}

fn main() {
    f::<'static>();
    //~^ ERROR expected at most 0 lifetime parameters, found 1 lifetime parameter [E0088]
    //~| NOTE expected 0 lifetime parameters

    g::<'static, 'static>();
    //~^ ERROR expected at most 0 lifetime parameters, found 2 lifetime parameters [E0088]
    //~| NOTE expected 0 lifetime parameters
}
